@@ -162,6 +162,8 @@ class BaseTestCase(ExtendBaseTestCase):
         :param new_base: 新的 base，如 'https://new.example.com'
         :return: 替换后的 URL
         """
+        if url.startswith("http"):
+            return url
         parsed_url = urlparse(url)
         new_base_parsed = urlparse(new_base)
 
