@@ -13,6 +13,7 @@ from collections import OrderedDict
 from datetime import datetime, timedelta
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
+import dill
 import json
 import retry
 import allure
@@ -64,220 +65,15 @@ def context():
     yield context
 
 
+class Http(object): pass
+
+
 @retry.retry(tries=3, delay=1)
 @pytest.fixture(scope="function", autouse=True)
 def http():
     yield _FRAMEWORK_CONTEXT.get("_http")
 
 
-class Http(object):
-    ...
-
-
-def init_mysql():
-    """初始化 MySQL 连接池"""
-    try:
-        mysql_config = CONFIG.get(app=all_app[0], key="mysql")
-        mysql_conns = {item: MysqlDB(**mysql_config[item]) for item in mysql_config}
-        for app in all_app:
-            _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=mysql_conns)
-    except Exception as e:
-        raise MysqlDBError(e)
-
-
-def init_redis():
-    """初始化 Redis 连接池（16个db）"""
-    try:
-        redis_config = CONFIG.get(app=all_app[0], key="redis")
-        redis_conns = {
-            db: [RedisDB(**{**db_info, "db": i}) for i in range(16)]
-            for db, db_info in redis_config.items()
-        }
-        for app in all_app:
-            _FRAMEWORK_CONTEXT.set(app=app, key="redis", value=redis_conns)
-    except Exception as e:
-        raise RedisDBError(e)
-
-
-def inner_login(app):
-    """单个系统的登录和资源初始化"""
-
-    login_cls = getattr(module, f"{snake_to_pascal(app)}Login")
-    setattr(Http, app, login_cls(app))
-    # Token 过期时间写入上下文
-    token_expiry = CONTEXT.get(app).get("token_expiry")
-    if token_expiry:
-        expire_time = datetime.now() + timedelta(seconds=token_expiry)
-        _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
-
-
-def login():
-    def safe_call(func, name):
-        try:
-            logger.info(f"初始化{name}连接...")
-            func()
-            logger.info(f"{name}连接初始化成功")
-        except (MysqlDBError, RedisDBError) as e:
-            logger.error(f"{name}连接初始化异常: {e}")
-
-    # 启动 MySQL 和 Redis 初始化线程
-    threads = [
-        threading.Thread(target=safe_call, args=(init_mysql, "MySQL")),
-        threading.Thread(target=safe_call, args=(init_redis, "Redis"))
-    ]
-
-    for t in threads:
-        t.start()
-    for t in threads:
-        t.join()
-
-    logger.info("登录账号".center(80, "*"))
-    with ThreadPoolExecutor(max_workers=len(all_app)) as executor:
-        futures = {executor.submit(inner_login, app): app for app in all_app}
-        for future in as_completed(futures):
-            future.result()
-
-    logger.info("登录完成".center(80, "*"))
-    return Http
-
-
-def find_data_path_by_case(app, case_file_name):
-    """
-    基于case文件名称查找与之对应的yml文件路径
-    :param app:
-    :param case_file_name:
-    :return:
-    """
-    env = CONTEXT.get("env")
-    for file_path in Path(os.path.join(settings.DATA_DIR, env, app)).rglob(f"{case_file_name}.y*"):
-        if file_path:
-            return file_path
-
-
-def subset_and_diff(small: set, big: set):
-    """
-    判断 small 是否为 big 的子集，并返回差集
-    """
-    return small.issubset(big), small - big
-
-
-def disable_field(scenario, data):
-    if not scenario:
-        return data
-
-    def _clean(obj):
-        if isinstance(obj, dict):
-            keys_to_delete = []
-            for k, v in obj.items():
-                if isinstance(v, (dict, list)):
-                    _clean(v)
-                elif isinstance(v, str):
-                    for ak, av in scenario.items():
-                        if av == "disable" and v == f"${{{ak}}}":
-                            keys_to_delete.append(k)
-                            break
-            # 统一删除，避免边遍历边删
-            for k in keys_to_delete:
-                del obj[k]
-
-        elif isinstance(obj, list):
-            for item in obj:
-                if isinstance(item, (dict, list)):
-                    _clean(item)
-
-    _clean(data)
-    return data
-
-
-def match_keyword(keyword_expr: str, target_str: str) -> bool:
-    """
-    按规则匹配字符串：
-    - 空表达式：直接返回 True
-    - 单个关键词：直接 in 判断
-    - 多关键词：支持 and / or / not / 括号
-    """
-    if not keyword_expr.strip():
-        return True  # 空关键字，默认匹配所有
-
-    keyword_expr = keyword_expr.strip().lower()
-    target_str = target_str.lower()
-
-    # 单个关键词直接处理
-    words = re.findall(r"[^\s()]+", keyword_expr)  # 提取非括号非空格的词
-    if len(words) == 1:
-        return words[0] in target_str
-
-    # 带逻辑表达式
-    # tokens 保留括号，分离 and/or/not/关键词
-    tokens = re.findall(r"\(|\)|and|or|not|[^\s()]+", keyword_expr)
-
-    expr_list = []
-    for t in tokens:
-        if t in {"and", "or", "not", "(", ")"}:
-            expr_list.append(t)
-        else:
-            # 替换为 True/False
-            expr_list.append(str(t in target_str))
-
-    expr_str = " ".join(expr_list)
-    try:
-        return eval(expr_str)
-    except Exception as e:
-        logger.error(f"表达式解析错误: {e}, 表达式: {expr_str}")
-        return False
-
-
-def match_mark(keyword_expr: str, target_list: list[str]) -> bool:
-    """
-    按规则匹配目标列表：
-    - 空表达式：直接返回 True
-    - 单个关键词：精准匹配 target_list 中某个元素
-    - 多个关键词：支持 and/or/not/括号
-    """
-    if not keyword_expr.strip():
-        return True  # 空关键字，默认匹配所有
-
-    keyword_expr = keyword_expr.strip().lower()
-    target_list = [s.lower() for s in target_list]
-
-    def contains(word: str) -> bool:
-        """精准匹配：word 必须等于 target_list 的某个元素"""
-        return word in target_list
-
-    # tokens：保留括号，拆分 and/or/not/关键词
-    tokens = re.findall(r"\(|\)|and|or|not|[^\s()]+", keyword_expr)
-
-    expr_list = []
-    for t in tokens:
-        if t in {"and", "or", "not", "(", ")"}:
-            expr_list.append(t)
-        else:
-            expr_list.append(str(contains(t)))
-
-    expr_str = " ".join(expr_list)
-    try:
-        return eval(expr_str)
-    except Exception as e:
-        logger.error(f"表达式解析错误: {e}, 表达式: {expr_str}")
-        return False
-
-
-def init_allure(params):
-    """设置allure中case的 title, description, level"""
-    case_level_map = {
-        "p0": allure.severity_level.BLOCKER,
-        "p1": allure.severity_level.CRITICAL,
-        "p2": allure.severity_level.NORMAL,
-        "p3": allure.severity_level.MINOR,
-        "p4": allure.severity_level.TRIVIAL,
-    }
-    allure.dynamic.title(params.get("title"))
-    allure.dynamic.description(params.get("describe"))
-    allure.dynamic.severity(case_level_map.get(params.get("level")))
-    allure.dynamic.feature(params.get("module"))
-    allure.dynamic.story(params.get("describe"))
-
-
 def pytest_configure(config):
     """
     初始化时被调用，可以用于设置全局状态或配置
@@ -294,32 +90,13 @@ def pytest_configure(config):
     sys.path.append(settings.CASES_DIR)
 
 
-def pytest_unconfigure(config):
-    app = CONTEXT.get("app")
-    app_handlers = getattr(settings, "APP_FINISH_HANDLER_CLASSES", {})
-    if app:
-        handlers = app_handlers.get(app) or []
-    else:
-        handlers = [h for value in app_handlers.values() for h in value] or []
-    global_handlers = getattr(settings, "GLOBAL_FINISH_HANDLER_CLASSES", [])
-    handlers.extend(global_handlers)
-    for handler in handlers:
-        try:
-            module_path, class_name = handler.rsplit(".", 1)
-            cls = getattr(importlib.import_module(module_path), class_name)
-            cls().run()
-        except Exception as e:
-            logger.error(str(e))
-            traceback.print_exc()
-            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
-
-
 def pytest_generate_tests(metafunc):
     """
     生成（多个）对测试函数的参数化调用
     :param metafunc:
     :return:
     """
+
     keyword_expr = metafunc.config.getoption("keyword")
     mark_expr = metafunc.config.getoption("markexpr")
     node_id = metafunc.definition.keywords.node.nodeid
@@ -513,105 +290,6 @@ def pytest_collection_modifyitems(items):
                 item.add_marker(mark)
 
 
-# UPDATE 将用例 按类名进行分组的核心方法
-def filtered_groupby(iterable, key_func):
-    """生成器：过滤key_func返回None的元素，并按key_func分组"""
-    current_key = None
-    current_group = []
-
-    for item in iterable:
-        key = key_func(item)
-        if key is None:
-            continue  # 跳过key为None的元素
-
-        # 处理分组逻辑（类似groupby）
-        if key != current_key:
-            if current_group:
-                yield current_key, current_group
-            current_key = key
-            current_group = [item]
-        else:
-            current_group.append(item)
-
-    # 输出最后一组
-    if current_group:
-        yield current_key, current_group
-
-
-# UPDATE：按类的全路径 进行用例分组 同一个类的test方法分到一组
-def __get_group_key__(item):
-    return '::'.join(item.nodeid.split('::')[:2])
-
-
-# UPDATE：改变pytest的原始排序规则
-def sort(case_items):
-    # 按测试类全路径分类,同一个类文件的用例归集到一起
-    # 使用 groupby 函数进行分组
-    item_group_list = [list(group) for _, group in filtered_groupby(case_items, __get_group_key__)]
-
-    all_item_list = []
-    clase_id = None
-    for items in item_group_list:
-        # 未被test_setup/test_teardown 标记的test方法
-        non_custom_scope_items = [item for item in items if
-                                  'test_setup' != item.originalname and 'test_teardown' != item.originalname]
-        item_list = []
-        # 用例的组数
-        case_suite_num = 0
-        # 生成每个组当前的索引
-        ori_name_temp = None
-        ori_name_list = []
-
-        for item in non_custom_scope_items:
-            clase_id = item.cls.__name__
-            original_name = item.originalname
-
-            if ori_name_temp is None or ori_name_temp == original_name:
-                ori_name_temp = original_name
-                case_suite_num += 1
-                ori_name_list.append([original_name, item])
-            else:
-                break
-
-        # 根据组数 创建各组的数组 并插入第一个case
-        case_dict = dict()
-        try:
-            for i in range(case_suite_num):
-                item = ori_name_list[i][1]
-                id = item.callspec.id
-
-                first_part = id.split('#', 1)[-1]
-                index = first_part.split(']')[0]
-                case_dict[index] = [item]
-        except:
-            pass
-
-        new_start_index = case_suite_num
-        # 以new_start_index为起点 重新遍历items
-        try:
-            for i in range(new_start_index, len(non_custom_scope_items)):
-                item = non_custom_scope_items[i]
-                id = item.callspec.id
-                first_part = id.split('#', 1)[-1]
-                index = first_part.split(']')[0]
-                case_dict.get(index).append(item)
-        except:
-            pass
-
-        index = 0
-        for id in case_dict:
-            index += 1
-            case_item_list = case_dict.get(id)
-            for item in case_item_list:
-                allure_suite_mark = f'{clase_id}#{index}'
-                setattr(item, 'allure_suite_mark', allure_suite_mark)
-            item_list += case_item_list
-
-        all_item_list += item_list
-
-    return all_item_list
-
-
 def pytest_collection_finish(session):
     """获取最终排序后的 items 列表"""
     logger.info(f"共收集到 {len(session.items)} 个测试用例")
@@ -678,6 +356,26 @@ def pytest_runtestloop(session):
             pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
 
 
+def pytest_sessionfinish(session, exitstatus):
+    app = CONTEXT.get("app")
+    app_handlers = getattr(settings, "APP_FINISH_HANDLER_CLASSES", {})
+    if app:
+        handlers = app_handlers.get(app) or []
+    else:
+        handlers = [h for value in app_handlers.values() for h in value] or []
+    global_handlers = getattr(settings, "GLOBAL_FINISH_HANDLER_CLASSES", [])
+    handlers.extend(global_handlers)
+    for handler in handlers:
+        try:
+            module_path, class_name = handler.rsplit(".", 1)
+            cls = getattr(importlib.import_module(module_path), class_name)
+            cls().run()
+        except Exception as e:
+            logger.error(str(e))
+            traceback.print_exc()
+            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
+
+
 def pytest_runtest_setup(item):
     allure.dynamic.sub_suite(item.allure_suite_mark)
     if item.funcargs.get("first"):
@@ -841,3 +539,304 @@ def pytest_exception_interact(node, call, report):
     """
     if call.excinfo.type is AssertionError:
         logger.error(f"{node.nodeid} failed: {call.excinfo.value}\n")
+
+
+def init_mysql():
+    """初始化 MySQL 连接池"""
+    try:
+        mysql_config = CONFIG.get(app=all_app[0], key="mysql")
+        mysql_conns = {item: MysqlDB(**mysql_config[item]) for item in mysql_config}
+        for app in all_app:
+            _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=mysql_conns)
+    except Exception as e:
+        raise MysqlDBError(e)
+
+
+def init_redis():
+    """初始化 Redis 连接池（16个db）"""
+    try:
+        redis_config = CONFIG.get(app=all_app[0], key="redis")
+        redis_conns = {
+            db: [RedisDB(**{**db_info, "db": i}) for i in range(16)]
+            for db, db_info in redis_config.items()
+        }
+        for app in all_app:
+            _FRAMEWORK_CONTEXT.set(app=app, key="redis", value=redis_conns)
+    except Exception as e:
+        raise RedisDBError(e)
+
+
+def inner_login(app):
+    """单个系统的登录和资源初始化"""
+
+    login_cls = getattr(module, f"{snake_to_pascal(app)}Login")
+    setattr(Http, app, login_cls(app))
+    # Token 过期时间写入上下文
+    token_expiry = CONTEXT.get(app).get("token_expiry")
+    if token_expiry:
+        expire_time = datetime.now() + timedelta(seconds=token_expiry)
+        _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
+
+def login():
+    def safe_call(func, name):
+        try:
+            logger.info(f"初始化{name}连接...")
+            func()
+            logger.info(f"{name}连接初始化成功")
+        except (MysqlDBError, RedisDBError) as e:
+            logger.error(f"{name}连接初始化异常: {e}")
+
+    # 启动 MySQL 和 Redis 初始化线程
+    threads = [
+        threading.Thread(target=safe_call, args=(init_mysql, "MySQL")),
+        threading.Thread(target=safe_call, args=(init_redis, "Redis"))
+    ]
+
+    for t in threads:
+        t.start()
+    for t in threads:
+        t.join()
+    logger.info("登录账号".center(80, "*"))
+    with ThreadPoolExecutor(max_workers=len(all_app)) as executor:
+        futures = {executor.submit(inner_login, app): app for app in all_app}
+        for future in as_completed(futures):
+            future.result()
+
+    logger.info("登录完成".center(80, "*"))
+    return Http
+
+
+def find_data_path_by_case(app, case_file_name):
+    """
+    基于case文件名称查找与之对应的yml文件路径
+    :param app:
+    :param case_file_name:
+    :return:
+    """
+    env = CONTEXT.get("env")
+    for file_path in Path(os.path.join(settings.DATA_DIR, env, app)).rglob(f"{case_file_name}.y*"):
+        if file_path:
+            return file_path
+
+
+def subset_and_diff(small: set, big: set):
+    """
+    判断 small 是否为 big 的子集，并返回差集
+    """
+    return small.issubset(big), small - big
+
+
+def disable_field(scenario, data):
+    if not scenario:
+        return data
+
+    def _clean(obj):
+        if isinstance(obj, dict):
+            keys_to_delete = []
+            for k, v in obj.items():
+                if isinstance(v, (dict, list)):
+                    _clean(v)
+                elif isinstance(v, str):
+                    for ak, av in scenario.items():
+                        if av == "disable" and v == f"${{{ak}}}":
+                            keys_to_delete.append(k)
+                            break
+            # 统一删除，避免边遍历边删
+            for k in keys_to_delete:
+                del obj[k]
+
+        elif isinstance(obj, list):
+            for item in obj:
+                if isinstance(item, (dict, list)):
+                    _clean(item)
+
+    _clean(data)
+    return data
+
+
+def match_keyword(keyword_expr: str, target_str: str) -> bool:
+    """
+    按规则匹配字符串：
+    - 空表达式：直接返回 True
+    - 单个关键词：直接 in 判断
+    - 多关键词：支持 and / or / not / 括号
+    """
+    if not keyword_expr.strip():
+        return True  # 空关键字，默认匹配所有
+
+    keyword_expr = keyword_expr.strip().lower()
+    target_str = target_str.lower()
+
+    # 单个关键词直接处理
+    words = re.findall(r"[^\s()]+", keyword_expr)  # 提取非括号非空格的词
+    if len(words) == 1:
+        return words[0] in target_str
+
+    # 带逻辑表达式
+    # tokens 保留括号，分离 and/or/not/关键词
+    tokens = re.findall(r"\(|\)|and|or|not|[^\s()]+", keyword_expr)
+
+    expr_list = []
+    for t in tokens:
+        if t in {"and", "or", "not", "(", ")"}:
+            expr_list.append(t)
+        else:
+            # 替换为 True/False
+            expr_list.append(str(t in target_str))
+
+    expr_str = " ".join(expr_list)
+    try:
+        return eval(expr_str)
+    except Exception as e:
+        logger.error(f"表达式解析错误: {e}, 表达式: {expr_str}")
+        return False
+
+
+def match_mark(keyword_expr: str, target_list: list[str]) -> bool:
+    """
+    按规则匹配目标列表：
+    - 空表达式：直接返回 True
+    - 单个关键词：精准匹配 target_list 中某个元素
+    - 多个关键词：支持 and/or/not/括号
+    """
+    if not keyword_expr.strip():
+        return True  # 空关键字，默认匹配所有
+
+    keyword_expr = keyword_expr.strip().lower()
+    target_list = [s.lower() for s in target_list]
+
+    def contains(word: str) -> bool:
+        """精准匹配：word 必须等于 target_list 的某个元素"""
+        return word in target_list
+
+    # tokens：保留括号，拆分 and/or/not/关键词
+    tokens = re.findall(r"\(|\)|and|or|not|[^\s()]+", keyword_expr)
+
+    expr_list = []
+    for t in tokens:
+        if t in {"and", "or", "not", "(", ")"}:
+            expr_list.append(t)
+        else:
+            expr_list.append(str(contains(t)))
+
+    expr_str = " ".join(expr_list)
+    try:
+        return eval(expr_str)
+    except Exception as e:
+        logger.error(f"表达式解析错误: {e}, 表达式: {expr_str}")
+        return False
+
+
+def init_allure(params):
+    """设置allure中case的 title, description, level"""
+    case_level_map = {
+        "p0": allure.severity_level.BLOCKER,
+        "p1": allure.severity_level.CRITICAL,
+        "p2": allure.severity_level.NORMAL,
+        "p3": allure.severity_level.MINOR,
+        "p4": allure.severity_level.TRIVIAL,
+    }
+    allure.dynamic.title(params.get("title"))
+    allure.dynamic.description(params.get("describe"))
+    allure.dynamic.severity(case_level_map.get(params.get("level")))
+    allure.dynamic.feature(params.get("module"))
+    allure.dynamic.story(params.get("describe"))
+
+
+# UPDATE 将用例 按类名进行分组的核心方法
+def filtered_groupby(iterable, key_func):
+    """生成器：过滤key_func返回None的元素，并按key_func分组"""
+    current_key = None
+    current_group = []
+
+    for item in iterable:
+        key = key_func(item)
+        if key is None:
+            continue  # 跳过key为None的元素
+
+        # 处理分组逻辑（类似groupby）
+        if key != current_key:
+            if current_group:
+                yield current_key, current_group
+            current_key = key
+            current_group = [item]
+        else:
+            current_group.append(item)
+
+    # 输出最后一组
+    if current_group:
+        yield current_key, current_group
+
+
+# UPDATE：按类的全路径 进行用例分组 同一个类的test方法分到一组
+def __get_group_key__(item):
+    return '::'.join(item.nodeid.split('::')[:2])
+
+
+# UPDATE：改变pytest的原始排序规则
+def sort(case_items):
+    # 按测试类全路径分类,同一个类文件的用例归集到一起
+    # 使用 groupby 函数进行分组
+    item_group_list = [list(group) for _, group in filtered_groupby(case_items, __get_group_key__)]
+
+    all_item_list = []
+    clase_id = None
+    for items in item_group_list:
+        # 未被test_setup/test_teardown 标记的test方法
+        non_custom_scope_items = [item for item in items if
+                                  'test_setup' != item.originalname and 'test_teardown' != item.originalname]
+        item_list = []
+        # 用例的组数
+        case_suite_num = 0
+        # 生成每个组当前的索引
+        ori_name_temp = None
+        ori_name_list = []
+
+        for item in non_custom_scope_items:
+            clase_id = item.cls.__name__
+            original_name = item.originalname
+
+            if ori_name_temp is None or ori_name_temp == original_name:
+                ori_name_temp = original_name
+                case_suite_num += 1
+                ori_name_list.append([original_name, item])
+            else:
+                break
+
+        # 根据组数 创建各组的数组 并插入第一个case
+        case_dict = dict()
+        try:
+            for i in range(case_suite_num):
+                item = ori_name_list[i][1]
+                id = item.callspec.id
+
+                first_part = id.split('#', 1)[-1]
+                index = first_part.split(']')[0]
+                case_dict[index] = [item]
+        except:
+            pass
+
+        new_start_index = case_suite_num
+        # 以new_start_index为起点 重新遍历items
+        try:
+            for i in range(new_start_index, len(non_custom_scope_items)):
+                item = non_custom_scope_items[i]
+                id = item.callspec.id
+                first_part = id.split('#', 1)[-1]
+                index = first_part.split(']')[0]
+                case_dict.get(index).append(item)
+        except:
+            pass
+
+        index = 0
+        for id in case_dict:
+            index += 1
+            case_item_list = case_dict.get(id)
+            for item in case_item_list:
+                allure_suite_mark = f'{clase_id}#{index}'
+                setattr(item, 'allure_suite_mark', allure_suite_mark)
+            item_list += case_item_list
+
+        all_item_list += item_list
+
+    return all_item_list
