@@ -18,18 +18,19 @@ from framework.utils.log_util import logger
 from framework.global_attribute import CONTEXT
 from config.settings import CONSOLE_DETAILED_LOG
 from framework.utils.common import convert_numbers_to_decimal
-from framework.exceptions import RequestException, ResponseException
+from framework.exceptions import RequestException
 
 
 class ResponseUtil(object):
     def __init__(self, response: Response):
-        if not response.content:
-            raise ResponseException(response.text)
-
         self.response = response
-        content_type = response.headers.get("Content-Type", "").lower()
+
+        if not response.content:
+            self.box = response.text
+            return
 
         try:
+            content_type = response.headers.get("Content-Type", "").lower()
             # JSON 类型
             if "application/json" in content_type:
                 data = self.response.json()
@@ -56,7 +57,7 @@ class ResponseUtil(object):
                 self.box = self.response.content
 
         except Exception as e:
-            raise ResponseException(f"{e}: {response.text}")
+            self.box = response.text
 
     def __getattr__(self, name):
         try:
@@ -90,6 +91,10 @@ class ResponseUtil(object):
     def json(self):
         return self.response.json()
 
+    @property
+    def text(self):
+        return self.response.text
+
     def extract(self, app, key, expression):
         """
         进行变量提取
@@ -169,8 +174,8 @@ class HttpClient(object):
                 if CONSOLE_DETAILED_LOG:
                     logger.info(f"响应headers: {HttpClient.json(dict(self.response.headers))}")
 
-            with allure.step(f"响应body: {HttpClient.json(self.response.json())}"):
-                logger.info(f"响应body: {HttpClient.json(self.response.json())}")
+            with allure.step(f"响应body: {self.response.text}"):
+                logger.info(f"响应body: {self.response.text}")
 
         # 断言
         validates = data.get("validate")
